@@ -5,11 +5,12 @@ import numpy as np
 from matplotlib import pyplot as plt
 
 try:
-    from skimage.transform import rotate as sk_rotate
+    # from skimage.transform import rotate as sk_rotate
     from skimage.util import random_noise
     from skimage.filters import gaussian
-    from PIL import Image as PIL_Image
-except Exception as exp:
+
+    # from PIL import Image as PIL_Image
+except Exception:
     # print("Install skimage, Pillow.", exp)
     pass
 # from scipy.ndimage import rotate
@@ -168,6 +169,9 @@ class Image(object):
     ):
         """Crop squarre from an image."""
         # For STM image, use min_size=50
+
+        from PIL import Image as PIL_Image
+
         if image_arr is not None:
             if greyscale:
                 pil_image = PIL_Image.fromarray(
@@ -206,6 +210,8 @@ class Image(object):
         suffix=".png",
     ):
         """Augment images using skimage."""
+        from skimage.transform import rotate as sk_rotate
+
         if image_arr is None:
             img_arr = plt.imread(image_path)
         else:
